import {create} from "zustand";
import {produce} from "immer";
import {persist, createJSONStorage} from "zustand/middleware";
import AsynStorage from "@react-native-async-storage/async-storage";
import DonutData from "../data/DonutData";
import DrinkData from "../data/DrinkData";

export const useStore = create(
    persist(
        (set, get) => ({
            AllDonutList1: DonutData,
            AllDrinkList: DrinkData,
            CartPrice: 0,
            FavoriteList: [],
            CartList: [],
            ReceiptList: [],
            addToCart:(cartItem: any) => 
                set(
                    produce(state => {
                        let found = false;
                        for(let i = 0; i < state.CartList.length; i++){
                            if(state.CartList[i].id == cartItem.id){
                                found = true;
                                let size = false;
                                for(let j = 0; j < state.CartList[i].prices.length; j++){
                                    if(state.CartList[i].prices[j].size == cartItem.prices[0].size){
                                        size = true;
                                        state.CartList[i].prices[j].quantity++;
                                        break;
                                    }
                                }
                                if(size == false){
                                    state.CartList[i].prices.push(cartItem.prices[0]);
                                }
                                state.CartList[i].prices.sort((a: any, b: any) => {
                                    if(a.size > b.size){
                                        return -1;
                                    }
                                    if(a.size < b.size) {
                                        return 1;
                                    }
                                    return 0;
                                });
                                break;
                            }
                        }
                        if(found == false){
                            state.CartList.push(cartItem)
                        }
                    }),
                ),
            calculateCartPrice:() =>
                set(
                    produce(state => {
                        let totalPrice = 0;
                        for(let i = 0; i < state.CartList.length; i++){
                            let tempPrice = 0;
                            for(let j = 0; j < state.CartList[i].prices.length; j++){
                                tempPrice = tempPrice + parseFloat(state.CartList[i].prices[j].price) * state.CartList[i].prices[j].quantity;
                            }
                            state.CartList[i].ItemPrice = tempPrice.toFixed(2).toString();
                            totalPrice = totalPrice + tempPrice;
                        }
                        state.CartPrice = totalPrice.toFixed(2).toString();
                    })
                ),
            addToFavoriteList:(type: string, id: string) => 
                set(
                    produce(state => {
                        if(type == 'Donut'){
                            for(let i = 0; i < state.AllDonutList1.length; i++){
                                if(state.AllDonutList1[i].id == id){
                                    if(state.AllDonutList1[i].favourite == false){
                                        state.AllDonutList1[i].favourite = true;
                                        state.FavoriteList.unshift(state.AllDonutList1[i]);
                                    } else{
                                        state.AllDonutList1[i].favourite = false;
                                    }
                                    break;
                                }
                            }
                        } else if(type == 'Drink'){
                            for(let i = 0; i< state.AllDrinkList.length; i++){
                                if(state.AllDrinkList[i].id == id){
                                    if(state.AllDrinkList[i].favourite == false){
                                        state.AllDrinkList[i].favourite = true;
                                        state.FavoriteList.unshift(state.AllDrinkList[i]);
                                    } else{
                                        state.AllDrinkList[i].favourite = false;
                                    }
                                    break;
                                }
                            }
                        }
                    })
                ),
            deleteFromFavoriteList:(type: string, id: string) => 
                set(
                    produce(state => {
                        if(type = 'Donut'){
                            for(let i = 0; i < state.AllDonutList1.length; i++){
                                if(state.AllDonutList1[i].id == id){
                                    if(state.AllDonutList1[i].favourite == true){
                                        state.AllDonutList1[i].favourite = false;
                                    } else{
                                        state.AllDonutList1[i].favourite = true;
                                    }
                                    break;
                                }
                            }
                        } else if(type = 'Drink'){
                            for(let i = 0; i < state.AllDrinkList.length; i++){
                                if(state.AllDrinkList[i].id == id){
                                    if(state.AllDrinkList[i].favourite == true){
                                        state.AllDrinkList[i].favourite = false;
                                    } else{
                                        state.AllDrinkList[i].favourite = true;
                                    }
                                    break;
                                }
                            }
                        }
                        let spliceIndex = -1;
                        for(let i = 0; i < state.FavoriteList.length; i++){
                            if (state.FavoriteList[i].id == id){
                                spliceIndex = i;
                                break;
                            }
                        }
                        state.FavoriteList.splice(spliceIndex, 1);
                    }),
                ),
        }), 
        {
            name: 'donutshop',
            storage: createJSONStorage(() => AsynStorage),
        }
    ),
)
